==> jc-1.4.0.tar.gz: java/lang/ref/Reference.h <==
// public abstract class java.lang.ref.Reference

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 77273604094666c7 java_lang_ref_Reference

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_ref_Reference_H_
#define _JC_java_lang_ref_Reference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ref_Reference$object;
struct _jc_java_lang_ref_ReferenceQueue$object;

// Typedefs
typedef struct _jc_java_lang_ref_Reference$sub_refs	_jc_java_lang_ref_Reference$sub_refs;
typedef struct _jc_java_lang_ref_Reference$sub_nonrefs	_jc_java_lang_ref_Reference$sub_nonrefs;
typedef struct _jc_java_lang_ref_Reference$refs	_jc_java_lang_ref_Reference$refs;
typedef struct _jc_java_lang_ref_Reference$nonrefs	_jc_java_lang_ref_Reference$nonrefs;
typedef struct _jc_java_lang_ref_Reference$object	_jc_java_lang_ref_Reference$object;

typedef struct _jc_java_lang_ref_Reference$fields_struct	_jc_java_lang_ref_Reference$fields_struct;
typedef const struct _jc_java_lang_ref_Reference$vmethods	_jc_java_lang_ref_Reference$vmethods;
typedef const struct _jc_java_lang_ref_Reference$vtable	_jc_java_lang_ref_Reference$vtable;
typedef const struct _jc_java_lang_ref_Reference$vtype	_jc_java_lang_ref_Reference$vtype;

// Class fields structure
struct _jc_java_lang_ref_Reference$fields_struct {
	struct _jc_java_lang_Object$object	*lock;
};
extern _jc_java_lang_ref_Reference$fields_struct _jc_java_lang_ref_Reference$class_fields;

// Constructors
extern void _jc_java_lang_ref_Reference$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_lang_ref_Reference$object *, struct _jc_java_lang_Object$object *);
extern void _jc_java_lang_ref_Reference$method$_init$5370f0fb4ab968c4(_jc_env *, struct _jc_java_lang_ref_Reference$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_ref_ReferenceQueue$object *);

// Virtual methods
extern void _jc_java_lang_ref_Reference$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_java_lang_ref_Reference$object *);
extern jboolean _jc_java_lang_ref_Reference$method$enqueue$bce1641dc181b3c0(_jc_env *, struct _jc_java_lang_ref_Reference$object *);
extern struct _jc_java_lang_Object$object *_jc_java_lang_ref_Reference$method$get$a27f05608bfbd09b(_jc_env *, struct _jc_java_lang_ref_Reference$object *);
extern jboolean _jc_java_lang_ref_Reference$method$isEnqueued$11351b94d4dfb051(_jc_env *, struct _jc_java_lang_ref_Reference$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_ref_Reference$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_java_lang_ref_Reference$method_info$enqueue$bce1641dc181b3c0;
extern _jc_method _jc_java_lang_ref_Reference$method_info$get$a27f05608bfbd09b;
extern _jc_method _jc_java_lang_ref_Reference$method_info$isEnqueued$11351b94d4dfb051;

// Static methods
extern void _jc_java_lang_ref_Reference$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_lang_ref_Reference$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_java_lang_ref_Reference$object *);
	jboolean	(*enqueue$bce1641dc181b3c0)(_jc_env *, struct _jc_java_lang_ref_Reference$object *);
	struct _jc_java_lang_Object$object	*(*get$a27f05608bfbd09b)(_jc_env *, struct _jc_java_lang_ref_Reference$object *);
	jboolean	(*isEnqueued$11351b94d4dfb051)(_jc_env *, struct _jc_java_lang_ref_Reference$object *);
};

// Vtable
struct _jc_java_lang_ref_Reference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_Reference$vmethods	java_lang_ref_Reference;
};

// Vtype
struct _jc_java_lang_ref_Reference$vtype {
	_jc_type			type;
	_jc_java_lang_ref_Reference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ref_Reference$sub_refs {
	struct _jc_java_lang_Object$object	*referent;
	struct _jc_java_lang_ref_ReferenceQueue$object	*queue;
	struct _jc_java_lang_ref_Reference$object	*nextOnQueue;
};

// Reference instance fields (object)
struct _jc_java_lang_ref_Reference$refs {
    _jc_java_lang_ref_Reference$sub_refs	java_lang_ref_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ref_Reference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ref_Reference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_Reference$sub_nonrefs	java_lang_ref_Reference;
};

// Object instance structure
struct _jc_java_lang_ref_Reference$object {
	_jc_java_lang_ref_Reference$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ref_Reference$vtype	*vtype;
	_jc_java_lang_ref_Reference$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ref_Reference$vtype _jc_java_lang_ref_Reference$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ref_Reference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ref_Reference$class_object;

#endif	/* _JC_java_lang_ref_Reference_H_ */

==> jc-1.4.6.tar.gz: java/lang/ref/Reference.h <==
// public abstract class java.lang.ref.Reference

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 77273604094666c7 java_lang_ref_Reference

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_ref_Reference_H_
#define _JC_java_lang_ref_Reference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ref_Reference$object;
struct _jc_java_lang_ref_ReferenceQueue$object;

// Typedefs
typedef struct _jc_java_lang_ref_Reference$sub_refs	_jc_java_lang_ref_Reference$sub_refs;
typedef struct _jc_java_lang_ref_Reference$sub_nonrefs	_jc_java_lang_ref_Reference$sub_nonrefs;
typedef struct _jc_java_lang_ref_Reference$refs	_jc_java_lang_ref_Reference$refs;
typedef struct _jc_java_lang_ref_Reference$nonrefs	_jc_java_lang_ref_Reference$nonrefs;
typedef struct _jc_java_lang_ref_Reference$object	_jc_java_lang_ref_Reference$object;

typedef struct _jc_java_lang_ref_Reference$fields_struct	_jc_java_lang_ref_Reference$fields_struct;
typedef const struct _jc_java_lang_ref_Reference$vmethods	_jc_java_lang_ref_Reference$vmethods;
typedef const struct _jc_java_lang_ref_Reference$vtable	_jc_java_lang_ref_Reference$vtable;
typedef const struct _jc_java_lang_ref_Reference$vtype	_jc_java_lang_ref_Reference$vtype;

// Class fields structure
struct _jc_java_lang_ref_Reference$fields_struct {
	struct _jc_java_lang_Object$object	*lock;
};
extern _jc_java_lang_ref_Reference$fields_struct _jc_java_lang_ref_Reference$class_fields;

// Constructors
extern void _jc_java_lang_ref_Reference$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_lang_ref_Reference$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ref_Reference$method$_init$5370f0fb4ab968c4(_jc_env *, struct _jc_java_lang_ref_Reference$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_ref_ReferenceQueue$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_lang_ref_Reference$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_java_lang_ref_Reference$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_ref_Reference$method$enqueue$bce1641dc181b3c0(_jc_env *, struct _jc_java_lang_ref_Reference$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_lang_ref_Reference$method$get$a27f05608bfbd09b(_jc_env *, struct _jc_java_lang_ref_Reference$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_ref_Reference$method$isEnqueued$11351b94d4dfb051(_jc_env *, struct _jc_java_lang_ref_Reference$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_ref_Reference$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_java_lang_ref_Reference$method_info$enqueue$bce1641dc181b3c0;
extern _jc_method _jc_java_lang_ref_Reference$method_info$get$a27f05608bfbd09b;
extern _jc_method _jc_java_lang_ref_Reference$method_info$isEnqueued$11351b94d4dfb051;

// Static methods
extern void _jc_java_lang_ref_Reference$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_ref_Reference$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_java_lang_ref_Reference$object *) _JC_JCNI_ATTR;
	jboolean	(*enqueue$bce1641dc181b3c0)(_jc_env *, struct _jc_java_lang_ref_Reference$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$a27f05608bfbd09b)(_jc_env *, struct _jc_java_lang_ref_Reference$object *) _JC_JCNI_ATTR;
	jboolean	(*isEnqueued$11351b94d4dfb051)(_jc_env *, struct _jc_java_lang_ref_Reference$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_ref_Reference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_Reference$vmethods	java_lang_ref_Reference;
};

// Vtype
struct _jc_java_lang_ref_Reference$vtype {
	_jc_type			type;
	_jc_java_lang_ref_Reference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ref_Reference$sub_refs {
	struct _jc_java_lang_Object$object	*referent;
	struct _jc_java_lang_ref_ReferenceQueue$object	*queue;
	struct _jc_java_lang_ref_Reference$object	*nextOnQueue;
};

// Reference instance fields (object)
struct _jc_java_lang_ref_Reference$refs {
    _jc_java_lang_ref_Reference$sub_refs	java_lang_ref_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ref_Reference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ref_Reference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_Reference$sub_nonrefs	java_lang_ref_Reference;
};

// Object instance structure
struct _jc_java_lang_ref_Reference$object {
	_jc_java_lang_ref_Reference$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ref_Reference$vtype	*vtype;
	_jc_java_lang_ref_Reference$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ref_Reference$vtype _jc_java_lang_ref_Reference$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ref_Reference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ref_Reference$class_object;

#endif	/* _JC_java_lang_ref_Reference_H_ */
